@@ -35,6 +35,8 @@
 #include "htmlengine-edit-fontstyle.h"
 #include "htmlsettings.h"
 
+#include "tt.xpm"
+
 
 #define EDITOR_TOOLBAR_PATH "/HTMLEditor"
 
@@ -199,7 +201,7 @@ color_changed (GtkWidget *w, GdkColor *gdk_color, GtkHTMLControlData *cd)
 		&& gdk_color != &html_colorset_get_color (cd->html->engine->settings->color_set, HTMLTextColor)->color
 		? html_color_new_from_gdk_color (gdk_color) : NULL;
 
-	html_engine_set_color (cd->html->engine, color);
+	gtk_html_set_color (cd->html, color);
 	if (color)
 		html_color_unref (color);
 }
@@ -220,6 +222,19 @@ setup_color_combo (GtkHTMLControlData *cd)
 
 /* Font style group.  */
 
+static void
+editor_toolbar_tt_cb (GtkWidget *widget, GtkHTMLControlData *cd)
+{
+	if (!cd->block_font_style_change) {
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
+			gtk_html_set_font_style (GTK_HTML (cd->html),
+						 GTK_HTML_FONT_STYLE_MAX,
+						 GTK_HTML_FONT_STYLE_FIXED);
+		else
+			gtk_html_set_font_style (GTK_HTML (cd->html), ~GTK_HTML_FONT_STYLE_FIXED, 0);
+	}
+}
+
 static void
 editor_toolbar_bold_cb (GtkWidget *widget, GtkHTMLControlData *cd)
 {
@@ -277,6 +292,11 @@ insertion_font_style_changed_cb (GtkHTML *widget, GtkHTMLFontStyle font_style, G
 {
 	cd->block_font_style_change = TRUE;
 
+	if (font_style & GTK_HTML_FONT_STYLE_FIXED)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cd->tt_button), TRUE);
+	else
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cd->tt_button), FALSE);
+
 	if (font_style & GTK_HTML_FONT_STYLE_BOLD)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cd->bold_button), TRUE);
 	else
@@ -398,24 +418,26 @@ editor_toolbar_unindent_cb (GtkWidget *widget,
 /* Editor toolbar.  */
 
 static GnomeUIInfo editor_toolbar_alignment_group[] = {
-	GNOMEUIINFO_ITEM_STOCK (N_("Left align"), N_("Left justify paragraphs"),
+	GNOMEUIINFO_ITEM_STOCK (N_("Left align"), N_("Left justifies the paragraphs"),
 				editor_toolbar_left_align_cb, GNOME_STOCK_PIXMAP_ALIGN_LEFT),
-	GNOMEUIINFO_ITEM_STOCK (N_("Center"), N_("Centers paragraphs"),
+	GNOMEUIINFO_ITEM_STOCK (N_("Center"), N_("Centers justifies the paragraphs"),
 				editor_toolbar_center_cb, GNOME_STOCK_PIXMAP_ALIGN_CENTER),
-	GNOMEUIINFO_ITEM_STOCK (N_("Right align"), N_("Right justify paragraphs"),
+	GNOMEUIINFO_ITEM_STOCK (N_("Right align"), N_("Right justifies the paragraphs"),
 				editor_toolbar_right_align_cb, GNOME_STOCK_PIXMAP_ALIGN_RIGHT),
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo editor_toolbar_style_uiinfo[] = {
 
-	{ GNOME_APP_UI_TOGGLEITEM, N_("Bold"), N_("Sets the bold font"),
+	{ GNOME_APP_UI_TOGGLEITEM, N_("Typewriter"), N_("Toggle typewriter font style"),
+	  editor_toolbar_tt_cb, NULL, NULL, GNOME_APP_PIXMAP_DATA, tt_xpm },
+	{ GNOME_APP_UI_TOGGLEITEM, N_("Bold"), N_("Makes the text bold"),
 	  editor_toolbar_bold_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_TEXT_BOLD },
-	{ GNOME_APP_UI_TOGGLEITEM, N_("Italic"), N_("Make the selection italic"),
+	{ GNOME_APP_UI_TOGGLEITEM, N_("Italic"), N_("Makes the text italic"),
 	  editor_toolbar_italic_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_TEXT_ITALIC },
-	{ GNOME_APP_UI_TOGGLEITEM, N_("Underline"), N_("Make the selection underlined"),
+	{ GNOME_APP_UI_TOGGLEITEM, N_("Underline"), N_("Underlines the text"),
 	  editor_toolbar_underline_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_TEXT_UNDERLINE },
-	{ GNOME_APP_UI_TOGGLEITEM, N_("Strikeout"), N_("Make the selection striked out"),
+	{ GNOME_APP_UI_TOGGLEITEM, N_("Strikeout"), N_("Strikes out the text"),
 	  editor_toolbar_strikeout_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_TEXT_STRIKEOUT },
 
 	GNOMEUIINFO_SEPARATOR,
@@ -424,9 +446,9 @@ static GnomeUIInfo editor_toolbar_style_uiinfo[] = {
 
 	GNOMEUIINFO_SEPARATOR,
 
-	GNOMEUIINFO_ITEM_STOCK (N_("Unindent"), N_("Indent paragraphs less"),
+	GNOMEUIINFO_ITEM_STOCK (N_("Unindent"), N_("Indents the paragraphs less"),
 				editor_toolbar_unindent_cb, GNOME_STOCK_PIXMAP_TEXT_UNINDENT),
-	GNOMEUIINFO_ITEM_STOCK (N_("Indent"), N_("Indent paragraphs more"),
+	GNOMEUIINFO_ITEM_STOCK (N_("Indent"), N_("Indents the paragraphs more"),
 				editor_toolbar_indent_cb, GNOME_STOCK_PIXMAP_TEXT_INDENT),
 
 	GNOMEUIINFO_END
@@ -481,11 +503,11 @@ create_style_toolbar (GtkHTMLControlData *cd)
 				      GTK_SIGNAL_FUNC (insertion_font_style_changed_cb), cd);
 
 	/* The following SUCKS!  */
-	cd->bold_button = editor_toolbar_style_uiinfo[0].widget;
-	cd->italic_button = editor_toolbar_style_uiinfo[1].widget;
-	cd->underline_button = editor_toolbar_style_uiinfo[2].widget;
-	cd->strikeout_button = editor_toolbar_style_uiinfo[3].widget;
-	/* (FIXME TODO: Button for "fixed" style.)  */
+	cd->tt_button        = editor_toolbar_style_uiinfo [0].widget;
+	cd->bold_button      = editor_toolbar_style_uiinfo [1].widget;
+	cd->italic_button    = editor_toolbar_style_uiinfo [2].widget;
+	cd->underline_button = editor_toolbar_style_uiinfo [3].widget;
+	cd->strikeout_button = editor_toolbar_style_uiinfo [4].widget;
 
 	cd->left_align_button = editor_toolbar_alignment_group[0].widget;
 	cd->center_button = editor_toolbar_alignment_group[1].widget;
