@@ -43,6 +43,7 @@ typedef enum {
 
 	GTK_HTML_COMMAND_DELETE,
 	GTK_HTML_COMMAND_DELETE_BACK,
+	GTK_HTML_COMMAND_DELETE_BACK_OR_INDENT_DEC,
 
 	GTK_HTML_COMMAND_SET_MARK,
 	GTK_HTML_COMMAND_DISABLE_SELECTION,
@@ -81,6 +82,7 @@ typedef enum {
 	GTK_HTML_COMMAND_INDENT_ZERO,
 	GTK_HTML_COMMAND_INDENT_INC,
 	GTK_HTML_COMMAND_INDENT_DEC,
+	GTK_HTML_COMMAND_INDENT_PARAGRAPH,
 
 	GTK_HTML_COMMAND_PARAGRAPH_STYLE_NORMAL,
 	GTK_HTML_COMMAND_PARAGRAPH_STYLE_H1,
