@@ -128,8 +128,10 @@ struct _GtkHTMLEditorAPI
 
 /* Creation.  */
 GtkType    gtk_html_get_type        (void);
+void       gtk_html_construct       (GtkWidget        *html);
 GtkWidget *gtk_html_new             (void);
-void       gtk_html_construct       (GtkWidget        *htmlw);
+GtkWidget *gtk_html_new_from_string (const gchar      *str,
+				     gint              len);
 void       gtk_html_set_editor_api  (GtkHTML          *html,
 				     GtkHTMLEditorAPI *api,
 				     gpointer          data);
