@@ -308,7 +308,7 @@ calc_min_width (HTMLObject *o,
 
 	cur = HTML_CLUE (o)->head;
 	while (cur) {
-		w += (add) ? html_object_calc_preferred_width (cur, painter) : html_object_calc_min_width (cur, painter);
+		w += add ? html_object_calc_preferred_width (cur, painter) : html_object_calc_min_width (cur, painter);
 		if (!add || cur->flags & HTML_OBJECT_FLAG_NEWLINE || !cur->next) {
 			if (min_width < w) min_width = w;
 			w = 0;
@@ -901,7 +901,7 @@ check_point (HTMLObject *self,
 		if (pnext == NULL || (pnext->y - pnext->ascent >= p->y + p->descent
 				      && y >= p->y - p->ascent
 				      && y <  p->y + p->descent)) {
-			obj = html_object_check_point (p, painter, p->x + p->width - 1, p->y + p->descent - 1,
+			obj = html_object_check_point (p, painter, MAX (0, p->x + p->width - 1), p->y + p->descent - 1,
 						       offset_return, for_cursor);
 			if (obj != NULL)
 				return obj;
@@ -910,7 +910,7 @@ check_point (HTMLObject *self,
 	/* after */
 	p = clue->tail;
 	if (x >= p->x + p->width || y >= p->y + p->descent) {
-		obj = html_object_check_point (p, painter, p->x + p->width - 1, p->y + p->descent - 1,
+		obj = html_object_check_point (p, painter, MAX (0, p->x + p->width - 1), p->y + p->descent - 1,
 					       offset_return, for_cursor);
 		if (obj != NULL)
 			return obj;
@@ -2085,8 +2085,12 @@ html_clueflow_spell_check (HTMLClueFlow *flow, HTMLEngine *e, HTMLInterval *inte
 			}
 		}
 		g_free (text);
-		html_interval_forall (interval, e, (HTMLObjectForallFunc) queue_draw, interval);
-		html_engine_flush_draw_queue (e);
+
+		if (!html_engine_frozen (e)) {
+			/* html_engine_queue_clear (e); */
+			html_interval_forall (interval, e, (HTMLObjectForallFunc) queue_draw, interval);
+			html_engine_flush_draw_queue (e);
+		}
 		html_interval_destroy (new_interval);
 	}
 }
