@@ -32,10 +32,10 @@
 #include "htmlcolor.h"
 #include "htmlcolorset.h"
 
-
 static HTMLPainterClass *parent_class = NULL;
 
-
+static EFontStyle e_style (GtkHTMLFontStyle style);
+
 /* GtkObject methods.  */
 
 static void
@@ -138,6 +138,27 @@ gtkhtml_private_split_name (gchar * c[], gchar * name)
 	c[i] = p;
 }
 
+static gchar *
+font_name_substitute_attr (const gchar *name, gint nth, gchar *val)
+{
+	const gchar *s;
+	gchar *s1, *s2, *rv;
+
+	for (s = name; nth; nth--) {
+		s = strchr (s, '-');
+		g_assert (s);
+		s ++;
+	}
+	s1 = g_strndup (name, s - name);
+	s2 = strchr (s, '-');
+	g_assert (s);
+
+	rv = g_strconcat (s1, val, s2, NULL);
+	g_free (s1);
+
+	return rv;
+}
+
 static gpointer
 alloc_e_font_it (gchar *face, gdouble size, GtkHTMLFontStyle style, gchar *it)
 {
@@ -146,17 +167,21 @@ alloc_e_font_it (gchar *face, gdouble size, GtkHTMLFontStyle style, gchar *it)
 
 
 	if (face) {
+		gchar *n1, *n2, *n3, *s;
 		gint tsize;
 
-		name = g_strdup_printf ("-*-%s-%s-%s-normal-*-*-*-*-*-*-*-*",
-					face, style & GTK_HTML_FONT_STYLE_BOLD ? "bold" : "medium",
-					style & GTK_HTML_FONT_STYLE_ITALIC ? it : "r");
-		if (!find_font (name, size, &tsize, style))
+		n1 = font_name_substitute_attr (face, 3, style & GTK_HTML_FONT_STYLE_BOLD ? "bold" : "medium");
+		n2 = font_name_substitute_attr (n1,   4, style & GTK_HTML_FONT_STYLE_ITALIC ? it : "r");
+		n3 = font_name_substitute_attr (n2,   7, "*");
+
+		if (!find_font (n3, size, &tsize, style))
 			tsize = size;
-		g_free (name);
-		name = g_strdup_printf ("-*-%s-%s-%s-normal-*-%d-*-*-*-*-*-*",
-					face, style & GTK_HTML_FONT_STYLE_BOLD ? "bold" : "medium",
-					style & GTK_HTML_FONT_STYLE_ITALIC ? it : "r", tsize);
+		g_free (n1);
+		g_free (n2);
+		s    = g_strdup_printf ("%d", tsize);
+		name = font_name_substitute_attr (n3,   7, s);
+		g_free (n3);
+		g_free (s);
 	} else
 		name = g_strdup ("fixed");
 
@@ -180,20 +205,34 @@ alloc_e_font_it (gchar *face, gdouble size, GtkHTMLFontStyle style, gchar *it)
 	return font;
 }
 
-static gpointer
-alloc_e_font (gchar *face, gdouble size, GtkHTMLFontStyle style)
+static HTMLFont *
+alloc_e_font (HTMLPainter *painter, gchar *face, gdouble size, GtkHTMLFontStyle style)
 {
-	
-
 	EFont *font;
 
 	font = alloc_e_font_it (face, size, style, "i");
 	if (!font && style & GTK_HTML_FONT_STYLE_ITALIC)
 		font = alloc_e_font_it (face, size, style, "o");
 
-	return font;
+	if (!font)
+		return NULL;
+
+	return html_font_new (font, e_font_utf8_text_width (font, e_style (style), " ", 1));
 }
 
+static void
+ref_font (HTMLPainter *painter, HTMLFont *font)
+{
+	e_font_ref ((EFont *) font->data);
+}
+
+static void
+unref_font (HTMLPainter *painter, HTMLFont *font)
+{
+	e_font_unref ((EFont *) font->data);
+}
+
+
 static void
 alloc_color (HTMLPainter *painter,
 	     GdkColor *color)
@@ -1093,8 +1132,8 @@ class_init (GtkObjectClass *object_class)
 	painter_class->begin = begin;
 	painter_class->end = end;
 	painter_class->alloc_font = alloc_e_font;
-	painter_class->ref_font   = (HTMLFontManagerRefFont)   e_font_ref;
-	painter_class->unref_font = (HTMLFontManagerUnrefFont) e_font_unref;
+	painter_class->ref_font   = ref_font;
+	painter_class->unref_font = unref_font;
 	painter_class->alloc_color = alloc_color;
 	painter_class->free_color = free_color;
 	painter_class->calc_ascent = calc_ascent;
