@@ -74,17 +74,18 @@ destroy (HTMLObject *o)
 	HTMLTableCell *cell;
 	guint r, c;
 
-	for (r = 0; r < table->allocRows; r++) {
-		for (c = 0; c < table->totalCols; c++) {
-			if ((cell = table->cells[r][c]) == 0)
-				continue;
-			if (cell->row != r || cell->col != c)
-				continue;
-
-			html_object_destroy (HTML_OBJECT (cell));
+	if (table->allocRows && table->totalCols)
+		for (r = table->allocRows - 1; ; r--) {
+			for (c = table->totalCols - 1; ; c--) {
+				if ((cell = table->cells[r][c]) && cell->row == r && cell->col == c)
+					html_object_destroy (HTML_OBJECT (cell));
+				if (c == 0)
+					break;
+			}
+			g_free (table->cells [r]);
+			if (r == 0)
+				break;
 		}
-		g_free (table->cells [r]);
-	}
 	g_free (table->cells);
 
 	g_array_free (table->columnMin, TRUE);
@@ -346,7 +347,6 @@ set_cell (HTMLTable *table, gint r, gint c, HTMLTableCell *cell)
 {
 	if (!table->cells [r][c]) {
 		table->cells [r][c] = cell;
-		html_table_cell_link (cell);
 		HTML_OBJECT (cell)->parent = HTML_OBJECT (table);
 	}
 }
@@ -1155,6 +1155,7 @@ check_point (HTMLObject *self,
 					return obj;
 			}
 		}
+
 		/* check after */
 		for (c=table->totalCols - 1; c >= 0; c--)
 			if (table->cells [start_row][c])
