@@ -328,7 +328,6 @@ html_table_cell_init (HTMLTableCell *cell,
 
 	cell->padding = 0;
 	cluev->padding = pad;
-	cell->refcount = 0;
 	cell->rspan = rs;
 	cell->cspan = cs;
 	cell->col = -1;
@@ -352,21 +351,6 @@ html_table_cell_new (gint percent,
 	return HTML_OBJECT (cell);
 }
 
-void
-html_table_cell_link (HTMLTableCell *cell)
-{
-	cell->refcount++;
-}
-
-void
-html_table_cell_unlink (HTMLTableCell *cell)
-{
-	cell->refcount--;
-
-	if (cell->refcount == 0)
-		html_object_destroy (HTML_OBJECT (cell));
-}
-
 void
 html_table_cell_set_fixed_width (HTMLTableCell *cell, gint width)
 {
