@@ -292,7 +292,7 @@ static GnomeFont *font;
 
 static void
 print_footer (GtkHTML *html, GnomePrintContext *context,
-	      gdouble x, gdouble y, gdouble width, gdouble height)
+	      gdouble x, gdouble y, gdouble width, gdouble height, gpointer user_data)
 {
 	gchar *text = g_strdup_printf ("- %d -", page_num);
 	gdouble tw = gnome_font_get_width_string (font, "text");
@@ -324,7 +324,7 @@ print_preview_cb (GtkWidget *widget,
 
 	page_num = 1;
 	font = gnome_font_new_closest ("Helvetica", GNOME_FONT_BOOK, FALSE, 12);
-	gtk_html_print_with_header_footer (html, print_context, .0, .03, NULL, print_footer);
+	gtk_html_print_with_header_footer (html, print_context, .0, .03, NULL, print_footer, NULL);
 	if (font) gtk_object_unref (GTK_OBJECT (font));
 
 	preview = GTK_WIDGET (gnome_print_master_preview_new (print_master, "HTML Print Preview"));
@@ -1034,7 +1034,7 @@ main (gint argc, gchar *argv[])
 	GtkWidget *app, *bar;
 	GtkWidget *html_widget;
 	GtkWidget *scrolled_window;
-	GdkColor   bgColor = {0, 0xc7ff, 0xc7ff, 0xc7ff};
+	/* GdkColor   bgColor = {0, 0xc7ff, 0xc7ff, 0xc7ff}; */
 	poptContext ctx;
 #ifdef GTKHTML_HAVE_GCONF
 	GError  *gconf_error  = NULL;
@@ -1088,7 +1088,7 @@ main (gint argc, gchar *argv[])
 	html_widget = gtk_html_new ();
 	html = GTK_HTML (html_widget);
 	gtk_html_load_empty (html);
-	gtk_html_set_default_background_color (GTK_HTML (html_widget), &bgColor);
+	/* gtk_html_set_default_background_color (GTK_HTML (html_widget), &bgColor); */
 	/* gtk_html_set_editable (GTK_HTML (html_widget), TRUE); */
 	
 	gtk_container_add (GTK_CONTAINER (scrolled_window), html_widget);
